==> lumibot-3.17.5.tar.gz: lumibot-3.17.5/lumibot/data_sources/example_broker_data.py <==
import logging
from decimal import Decimal
from typing import Union

from termcolor import colored
from lumibot.entities import Asset, Bars, Quote
from lumibot.data_sources import DataSource

class ExampleBrokerData(DataSource):
    """
    Data source that connects to the Example Broker API.
    """

    MIN_TIMESTEP = "minute"
    SOURCE = "ExampleBroker"

    def __init__(self, **kwargs):
        super().__init__()

    # Method stubs with logging for not yet implemented methods
    def get_chains(self, asset: Asset, quote: Asset = None) -> dict:
        logging.error(colored("Method 'get_chains' is not yet implemented.", "red"))
        return {}  # Return an empty dictionary as a placeholder

    def get_historical_prices(
        self, asset, length, timestep="", timeshift=None, quote=None, exchange=None, include_after_hours=True
    ) -> Bars:
        logging.error(colored("Method 'get_historical_prices' is not yet implemented.", "red"))
        return None  # Return None as a placeholder

    def get_last_price(self, asset, quote=None, exchange=None) -> Union[float, Decimal, None]:
        logging.error(colored("Method 'get_last_price' is not yet implemented.", "red"))
        return 0.0  # Return 0.0 as a placeholder

    def get_quote(self, asset: Asset, quote: Asset = None, exchange: str = None) -> Quote:
        """
        Get the latest quote for an asset.
        This is a placeholder implementation that returns an empty Quote object.

        Parameters
        ----------
        asset : Asset object
            The asset for which the quote is needed.
        quote : Asset object, optional
            The quote asset for cryptocurrency pairs.
        exchange : str, optional
            The exchange to get the quote from.

        Returns
        -------
        Quote
            A Quote object with the quote information.
        """
        logging.error(colored("Method 'get_quote' is not yet implemented.", "red"))
        return Quote(asset=asset)

==> lumibot-4.0.23.tar.gz: lumibot-4.0.23/lumibot/data_sources/example_broker_data.py <==
from decimal import Decimal
from typing import Union

from termcolor import colored

from lumibot.data_sources import DataSource
from lumibot.entities import Asset, Bars, Quote
from lumibot.tools.lumibot_logger import get_logger

logger = get_logger(__name__)

class ExampleBrokerData(DataSource):
    """
    Data source that connects to the Example Broker API.
    """

    MIN_TIMESTEP = "minute"
    SOURCE = "ExampleBroker"

    def __init__(self, **kwargs):
        super().__init__()

    # Method stubs with logging for not yet implemented methods
    def get_chains(self, asset: Asset, quote: Asset = None) -> dict:
        logger.error(colored("Method 'get_chains' is not yet implemented.", "red"))
        return {}  # Return an empty dictionary as a placeholder

    def get_historical_prices(
        self, asset, length, timestep="", timeshift=None, quote=None, exchange=None, include_after_hours=True
    ) -> Bars:
        logger.error(colored("Method 'get_historical_prices' is not yet implemented.", "red"))
        return None  # Return None as a placeholder

    def get_last_price(self, asset, quote=None, exchange=None) -> Union[float, Decimal, None]:
        logger.error(colored("Method 'get_last_price' is not yet implemented.", "red"))
        return 0.0  # Return 0.0 as a placeholder

    def get_quote(self, asset: Asset, quote: Asset = None, exchange: str = None) -> Quote:
        """
        Get the latest quote for an asset.
        This is a placeholder implementation that returns an empty Quote object.

        Parameters
        ----------
        asset : Asset object
            The asset for which the quote is needed.
        quote : Asset object, optional
            The quote asset for cryptocurrency pairs.
        exchange : str, optional
            The exchange to get the quote from.

        Returns
        -------
        Quote
            A Quote object with the quote information.
        """
        logger.error(colored("Method 'get_quote' is not yet implemented.", "red"))
        return Quote(asset=asset)
